Package: babette
Title: Control 'BEAST2'
Version: 2.3.4
Authors@R: c(
    person("Richèl J.C.", "Bilderbeek", email = "rjcbilderbeek@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-1107-7049")),
    person("Joëlle", "Barido-Sottani", role = "rev", comment = "Joëlle reviewed the package for rOpenSci, see https://github.com/richelbilderbeek/onboarding/issues/209"),
    person("David", "Winter", role = "rev", comment = "David reviewed the package for rOpenSci, see https://github.com/richelbilderbeek/onboarding/issues/209"),
    person("Jason", "Griffiths", role = "ctb", comment = c(ORCID = "0000-0002-1667-8233")),
    person("Olivier", "Roy", role = "ctb"),
    person("Giovanni", "Laudanno", email = "glaudanno@gmail.com", role = "ctb"))
Description: 'BEAST2' (<https://www.beast2.org>) is a widely used
    Bayesian phylogenetic tool, that uses DNA/RNA/protein data
    and many model priors to create a posterior of jointly estimated 
    phylogenies and parameters.
    'BEAST2' is commonly accompanied by 'BEAUti 2', 'Tracer' and 'DensiTree'.
    'babette' provides for an alternative workflow of using 
    all these tools separately. This allows doing complex Bayesian
    phylogenetics easily and reproducibly from 'R'. 
License: GPL-3
RoxygenNote: 7.2.3
VignetteBuilder: knitr
URL: https://docs.ropensci.org/babette/ (website),
        https://github.com/ropensci/babette
BugReports: https://github.com/ropensci/babette/issues
Depends: beautier (>= 2.6.12), beastier (>= 2.5), mauricer (>= 2.5.2),
        R (>= 3.5.0), tracerer
Imports: phangorn, rlang (>= 1.1.0), stringr, xml2
Suggests: ape, ggplot2, knitr, lintr, nLTT, rappdirs, rmarkdown,
        spelling, testthat (>= 2.1.0)
Language: en-US
Encoding: UTF-8
SystemRequirements: BEAST2 (https://www.beast2.org/)
NeedsCompilation: no
Packaged: 2024-06-24 09:17:09 UTC; richel
Author: Richèl J.C. Bilderbeek [aut, cre]
    (<https://orcid.org/0000-0003-1107-7049>),
  Joëlle Barido-Sottani [rev] (Joëlle reviewed the package for rOpenSci,
    see https://github.com/richelbilderbeek/onboarding/issues/209),
  David Winter [rev] (David reviewed the package for rOpenSci, see
    https://github.com/richelbilderbeek/onboarding/issues/209),
  Jason Griffiths [ctb] (<https://orcid.org/0000-0002-1667-8233>),
  Olivier Roy [ctb],
  Giovanni Laudanno [ctb]
Maintainer: Richèl J.C. Bilderbeek <rjcbilderbeek@gmail.com>
Repository: CRAN
Date/Publication: 2024-06-25 11:20:06 UTC
Built: R 4.6.0; ; 2026-04-30 18:50:34 UTC; unix
